def create_wordlist(filename):
    """
    Create a wordlist file with commonly used directory and file names.

    This function generates a wordlist containing common directory and file names used for directory enumeration.
    The wordlist is written to the specified filename.

    Args:
        filename (str): The name of the wordlist file to create.

    Example:
        create_wordlist("wordlist.txt")
    """
    wordlist = [
        "a",
        "b",
        "c",
        "d",
        "e",
        "f",
        "g",
        "h",
        "i",
        "j",
        "k",
        "l",
        "m",
        "n",
        "o",
        "p",
        "q",
        "r",
        "s",
        "t",
        "u",
        "v",
        "w",
        "x",
        "y",
        "z",
        "admin",
        "login",
        "images",
        "js",
        "css",
        "config",
        "index",
        "robots.txt",
        "backup",
        "secret",
        "support",
        "contact",
        "blog",
        "forum",
        "product",
        "category",
        "brand",
        "password",
        "123456",
        "qwerty",
        "letmein",
        "access",
        "admin123",
        "administrator",
        "superuser",
        "root",
        "test",
        # PHP apps
        "config/config.php",
        "includes/config.inc",
        
        # PHP apps
        "guest",
        "demo",
        "webmaster",
        "developer",
        "api",
        "api_key",
        "db",
        "database",
        "user",
        "users",
        "auth",
        "authentication",
        "login.php",
        "wp-admin",
        "wp-login.php",
        "upload",
        "uploads",
        "download",
        "downloads",
        "private",
        "public",
        "static",
        "media",
        "files",
        "file",
        "images/",
        "js/",
        "css/",
        "assets/",
        "images/uploads",
        "userfiles",
        "data",
        "temp",
        "temp/",
        "logs",
        "scripts",
        "web",
        "public_html",
        "secure",
        "private/",
        "backup/",
        "backup_files/",
        "conf",
        "config/",
        "configurations/",
        "install",
        "installer",
        "setup",
        "tmp",
        "db.sql",
        "data.sql",
        "users.sql",
        "passwords.txt",
        "passwd",
        "pass",
        "password.txt",
        "login.txt",
        "credentials",
        "phpmyadmin",
        "phpMyAdmin",
        "myadmin",
        "myAdmin",
        "panel",
        "control",
        "manager",
        "admin-panel",
        "admin-login",
        "signin",
        "sign-in",
        "login-form",
        "login.html",
        "login.aspx",
        "login.jsp",
        "signin.html",
        "signin.aspx",
        "signin.jsp",
        "register",
        "signup",
        "register.html",
        "register.aspx",
        "signup.html",
        "signup.aspx",
        "forgot-password",
        "forgot-password.html",
        "forgot-password.aspx",
        "reset-password",
        "reset-password.html",
        "reset-password.aspx",
        "contact-us",
        "contact.html",
        "contact.aspx",
        "contact-form",
        "support.html",
        "support.aspx",
        "support-form",
        "about-us",
        "about.html",
        "about.aspx",
        "faq",
        "faq.html",
        "faq.aspx",
        "terms",
        "terms.html",
        "terms.aspx",
        "privacy",
        "privacy.html",
        "privacy.aspx",
        "legal",
        "legal.html",
        "legal.aspx",
        "policy",
        "policy.html",
        "policy.aspx",
        "blog/",
        "news",
        "news.html",
        "news.aspx",
        "articles",
        "articles.html",
        "articles.aspx",
        "events",
        "events.html",
        "events.aspx",
        "products",
        "products.html",
        "products.aspx",
        "services",
        "services.html",
        "services.aspx",
        "portfolio",
        "portfolio.html",
        "portfolio.aspx",
        "gallery",
        "gallery.html",
        "gallery.aspx",
        "download/",
        "downloads/",
        "download-files",
        "download-file",
        "download.html",
        "download.aspx",
        "download.jsp",
        "upload/",
        "uploads/",
        "upload-file",
        "upload.html",
        "upload.aspx",
        "upload.jsp",
        "logout",
        "logout.html",
        "logout.aspx",
        "logout.jsp",
        "signout",
        "signout.html",
        "signout.aspx",
        "signout.jsp",
        "clients",
        "client",
        "adm",
        "db.sqlite",
        "db.sqlite3",
        "public_html/admin",
        "useruploads",
        "tempfiles",
        "logs/",
        "scripts/",
        "www",
        "htdocs",
        "site",
        "system",
        "platform",
        "app",
        "data/",
        "users/",
        "database/",
        "storage",
        "cache",
        "assets/",
        "lib",
        "include",
        "html",
        "htm",
        "php",
        "asp",
        "jsp",
        "exe",
        "bin",
        "dev",
        "config.php",
        "config.inc",
        "config.ini",
        "settings.php",
        "settings.inc",
        "settings.ini",
        "photo",
        "video",
        "hd",
        "HD",
        "home.php",
        "wp-content",
        "img/users/full/",
        "category",
        "index.php",
        "index.html",
        "index.jsp",
        "index.aspx",
        "index.htm",
        "of",
        "of/",
        "of.html",
        "of.aspx",
        "of.jsp",
        "index-of",
        "file",
        "files/",
        "files",
        "directory",
        "dir",
        "dir/",
        "dir.html",
        "dir.aspx",
        "dir.jsp",
        "list",
        "list.html",
        "list.aspx",
        "list.jsp",
        "view",
        "view.html",
        "view.aspx",
        "view.jsp",
        "explore",
        "explore.html",
        "explore.aspx",
        "explore.jsp",
        "browse",
        "browse.html",
        "browse.aspx",
        "browse.jsp",
        "content",
        "content.html",
        "content.aspx",
        "content.jsp",
        "show",
        "show.html",
        "show.aspx",
        "show.jsp",
        "display",
        "display.html",
        "display.aspx",
        "display.jsp",
        "fetch",
        "fetch.html",
        "fetch.aspx",
        "fetch.jsp",
        "get",
        "get.html",
        "get.aspx",
        "get.jsp",
        "retrieve",
        "retrieve.html",
        "retrieve.aspx",
        "retrieve.jsp",
        "access",
        "access.html",
        "access.aspx",
        "access.jsp",
        "open",
        "open.html",
        "open.aspx",
        "open.jsp",
        "read",
        "read.html",
        "read.aspx",
        "read.jsp",
        "logs",
        "logfiles",
        "access_logs",
        "error_logs",
        "security_logs",
        "event_logs",
        "audit_logs",
        "syslogs",
        "app_logs",
        "debug_logs",
        "traffic_logs",
        "server_logs",
        "apache_logs",
        "nginx_logs",
        "iis_logs",
        "web_logs",
        "firewall_logs",
        "proxy_logs",
        "database_logs",
        "application_logs",
        "error_log.txt",
        "access_log.txt",
        "security_log.txt",
        "event_log.txt",
        "audit_log.txt",
        "syslog.txt",
        "app_log.txt",
        "debug_log.txt",
        "traffic_log.txt",
        "server_log.txt",
        "apache_log.txt",
        "nginx_log.txt",
        "iis_log.txt",
        "web_log.txt",
        "firewall_log.txt",
        "proxy_log.txt",
        "database_log.txt",
        "application_log.txt",
        "log_backup",
        "log_archives",
        "log_history",
        "log_data",
        "log_files",
        "log_records",
        "log_entries",
        "log_storage",
        "log_management",
        "log_viewer",
        "log_analyzer",
        "log_parser",
        "log_monitoring",
        "log_security",
        "log_alerts",
        "log_analysis",
        "log_search",
        "log_export",
        "log_rotation",
        "log_cleanup",
        "log_rotation",
        "log_rotation_script",
        "log_rotation_config",
        "log_purge",
        "log_alert",
        "log_notifications",
        "log_errors",
        "log_warnings",
        "log_info",
        "log_debug",
        "log_critical",
        "log_alert",
        "log_emergency",
        "log_severity",
        "log_level",
        "log_timestamp",
        "log_date",
        "log_time",
        "log_ip",
        "log_user",
        "log_source",
        "log_destination",
        "log_event",
        "log_message",
        "log_code",
        "log_identifier",
        "log_category",
        "log_type",
        "log_origin",
        "log_target",
        "log_client",
        "log_server",
        "log_protocol",
        "log_response",
        "log_request",
        "log_access",
        "log_authentication",
        "log_authorization",
        "log_permission",
        "log_denied",
        "log_granted",
        "log_success",
        "log_failure",
        "log_login",
        "log_logout",
        "log_session",
        "log_session_id",
        "log_user_agent",
        "log_http",
        "log_https",
        "log_ftp",
        "log_ssh",
        "log_telnet",
        "log_smtp",
        "log_pop3",
        "log_imap",
        "log_dns",
        "log_database",
        "log_app",
        "log_firewall",
        "log_proxy",
        "log_vpn",
        "log_virus",
        "log_malware",
        "log_intrusion",
        "log_attack",
        "log_ddos",
        "log_security_event",
        "log_critical_event",
        "log_alert_event",
        "log_error_event",
        "log_warning_event",
        "log_info_event",
        "log_debug_event",
        "log_event_id",
        "log_event_type",
        "log_event_description",
        "log_event_details",
        "log_event_context",
        "log_event_origin",
        "log_event_destination",
        "log_event_source_ip",
        "log_event_target_ip",
        "log_event_timestamp",
        "log_event_date",
        "log_event_time",
        "log_event_user",
        "log_event_category",
        "log_event_severity",
        "log_event_level",
        "log_event_status",
        "log_event_response",
        "log_event_request",
        "log_event_access",
        "log_event_authentication",
        "log_event_authorization",
        "log_event_permission",
        "log_event_denied",
        "log_event_granted",
        "log_event_success",
        "log_event_failure",
        "log_event_login",
        "log_event_logout",
        "log_event_session",
        "log_event_session_id",
        "log_event_user_agent",
        "log_event_http",
        "log_event_https",
        "log_event_ftp",
        "log_event_ssh",
        "log_event_telnet",
        "log_event_smtp",
        "log_event_pop3",
        "log_event_imap",
        "log_event_dns",
        "log_event_database",
        "log_event_app",
        "log_event_firewall",
        "log_event_proxy",
        "log_event_vpn",
        "log_event_virus",
        "log_event_malware",
        "log_event_intrusion",
        "log_event_attack",
        "log_event_ddos",
        "log_event_security_alert",
        "log_event_critical_alert",
        "log_event_warning_alert",
        "log_event_info_alert",
        "log_event_debug_alert",
        "log_event_threat",
        "log_event_vulnerability",
        "log_event_incident",
        "log_event_response_time",
        "log_event_server_error",
        "log_event_client_error",
        "log_event_http_status",
        "log_event_http_code",
        "log_event_http_response",
        "log_event_http_request",
        "log_event_api",
        "log_event_configuration",
        "log_event_settings",
        "log_event_changes",
        "log_event_modification",
        "log_event_audit",
        "log_event_compliance",
        "log_event_policy",
        "log_event_rules",
        "log_event_user_activity",
        "log_event_admin_activity",
        "log_event_system_activity",
        "log_event_network_activity",
        "log_event_server_activity",
        "log_event_application_activity",
        "log_event_database_activity",
        "log_event_traffic",
        "log_event_bandwidth",
        "log_event_latency",
        "log_event_error_rate",
        "log_event_warning_rate",
        "log_event_info_rate",
        "log_event_debug_rate",
        "log_event_security_rate",
        "log_event_access_rate",
        "log_event_authentication_rate",
        "log_event_authorization_rate",
        "log_event_permission_rate",
        "log_event_denied_rate",
        "log_event_granted_rate",
        "log_event_success_rate",
        "log_event_failure_rate",
        "log_event_login_rate",
        "log_event_logout_rate",
        "log_event_session_rate",
        "log_event_session_id_rate",
        "log_event_user_agent_rate",
        "log_event_http_rate",
        "log_event_https_rate",
        "log_event_ftp_rate",
        "log_event_ssh_rate",
        "log_event_telnet_rate",
        "log_event_smtp_rate",
        "log_event_pop3_rate",
        "log_event_imap_rate",
        "log_event_dns_rate",
        "log_event_database_rate",
        "log_event_app_rate",
        "log_event_firewall_rate",
        "log_event_proxy",
        "sitemap",
        "sitemap.xml",
        "site-map",
        "site_map",
        "site-map.xml",
        "site_map.xml",
        "sitemap_html",
        "sitemap_html.xml",
        "sitemap_index",
        "sitemap_index.xml",
        "sitemap_index_html",
        "sitemap_index_html.xml",
        "sitemap_index_html.txt",
        "sitemap_index_html.gz",
        "sitemap_index_html.zip",
        "sitemap_index_html.tar",
        "sitemap_index_html.tar.gz",
        "sitemap_index_html.tar.bz2",
        "sitemap_index_html.7z",
        "sitemap_index_html.rar",
        "sitemap_index_html.tar.xz",
        "sitemap_index_html.tbz2",
        "sitemap_index_html.tbz",
        "sitemap_index_html.cpio",
        "sitemap_index_html.lz",
        "sitemap_index_html.lzma",
        "sitemap_index_html.Z",
        "sitemap_index_html.bz2",
        "sitemap_index_html.arj",
        "sitemap_index_html.deb",
        "sitemap_index_html.rpm",
        "sitemap_index_html.zipx",
        "sitemap_index_html.tgz",
        "sitemap_index_html.xz",
        "sitemap_index_html.cab",
        "sitemap_index_html.ace",
        "sitemap_index_html.wim",
        "sitemap_index_html.dmg",
        "sitemap_index_html.iso",
        "sitemap_index_html.vhd",
        "sitemap_index_html.vhdx",
        "sitemap_index_html.vmdk",
        "sitemap_index_html.udf",
        "sitemap_index_html.fat",
        "sitemap_index_html.ntfs",
        "sitemap_index_html.exfat",
        "sitemap_index_html.hfs",
        "sitemap_index_html.hfs+",
        "sitemap_index_html.btrfs",
        "sitemap_index_html.ext2",
        "sitemap_index_html.ext3",
        "sitemap_index_html.ext4",
        "sitemap_index_html.reiserfs",
        "sitemap_index_html.jfs",
        "sitemap_index_html.xfs",
        "sitemap_index_html.zfs",
        "sitemap_index_html.ufs",
        "sitemap_index_html.minix",
        "sitemap_index_html.apfs",
        "sitemap_index_html.hfsx",
        "sitemap_index_html.qnx",
        "sitemap_index_html.romfs",
        "sitemap_index_html.squashfs",
        "sitemap_index_html.ubifs",
        "sitemap_index_html.yaffs",
        "sitemap_index_html.ecryptfs",
        "sitemap_index_html.f2fs",
        "sitemap_index_html.nilfs",
        "sitemap_index_html.vxfs",
        "sitemap_index_html.gfs",
        "sitemap_index_html.cifs",
        "sitemap_index_html.nfs",
        "sitemap_index_html.afs",
        "sitemap_index_html.9p",
        "sitemap_index_html.npfs",
        "sitemap_index_html.fh",
        "sitemap_index_html.ofs",
        "sitemap_index_html.hpfs",
        "sitemap_index_html.befs",
        "sitemap_index_html.gpfs",
        "sitemap_index_html.wufs",
        "sitemap_index_html.cramfs",
        "sitemap_index_html.romfs",
        "sitemap_index_html.squashfs",
        "sitemap_index_html.ubifs",
        "sitemap_index_html.yaffs",
        "sitemap_index_html.ecryptfs",
        "sitemap_index_html.f2fs",
        "sitemap_index_html.nilfs",
        "sitemap_index_html.vxfs",
        "sitemap_index_html.gfs",
        "sitemap_index_html.cifs",
        "sitemap_index_html.nfs",
        "sitemap_index_html.afs",
        "sitemap_index_html.9p",
        "sitemap_index_html.npfs",
        "sitemap_index_html.fh",
        "sitemap_index_html.ofs",
        "sitemap_index_html.hpfs",
        "sitemap_index_html.befs",
        "sitemap_index_html.gpfs",
        "sitemap_index_html.wufs",
        "sitemap_index_html.cramfs",
        "sitemap_index_html.efs",
        "sitemap_index_html.ntfs3g",
        "sitemap_index_html.ufs",
        "sitemap_index_html.romfs",
        "sitemap_index_html.squashfs",
        "sitemap_index_html.ubifs",
        "sitemap_index_html.yaffs",
        "sitemap_index_html.ecryptfs",
        "sitemap_index_html.f2fs",
        "sitemap_index_html.nilfs",
        "sitemap_index_html.vxfs",
        "sitemap_index_html.gfs",
        "sitemap_index_html.cifs",
        "sitemap_index_html.nfs",
        "sitemap_index_html.afs",
        "sitemap_index_html.9p",
        "sitemap_index_html.npfs",
        "sitemap_index_html.fh",
        "sitemap_index_html.ofs",
        "sitemap_index_html.hpfs",
        "sitemap_index_html.befs",
        "sitemap_index_html.gpfs",
        "sitemap_index_html.wufs",
        "sitemap_index_html.cramfs",
        "sitemap_index_html.efs",
        "sitemap_index_html.ntfs3g",
        "sitemap_index_html.ufs",
        "sitemap_index_html.romfs",
        "sitemap_index_html.squashfs",
        "sitemap_index_html.ubifs",
        "sitemap_index_html.yaffs",
        "sitemap_index_html.ecryptfs",
        "sitemap_index_html.f2fs",
        "sitemap_index_html.nilfs",
        "sitemap_index_html.vxfs",
        "sitemap_index_html.gfs",
        "sitemap_index_html.cifs",
        "sitemap_index_html.nfs",
        "sitemap_index_html.afs",
        "sitemap_index_html.9p",
        "sitemap_index_html.npfs",
        "sitemap_index_html.fh",
        "sitemap_index_html.ofs",
        "sitemap_index_html.hpfs",
        "sitemap_index_html.befs",
        "sitemap_index_html.gpfs",
        "sitemap_index_html.wufs",
        "sitemap_index_html.cramfs",
        "sitemap_index_html.efs",
        "sitemap_index_html.ntfs3g",
        "sitemap_index_html.ufs",
        "sitemap_index_html.romfs",
        "sitemap_index_html.squashfs",
        "sitemap_index_html.ubifs",
        "sitemap_index_html.yaffs",
        "sitemap_index_html.ecryptfs",
        "sitemap_index_html.f2fs",
        "sitemap_index_html.nilfs",
        "sitemap_index_html.vxfs",
        "sitemap_index_html.gfs",
        "sitemap_index_html.cifs",
        "sitemap_index_html.nfs",
        "sitemap_index_html.afs",
        "sitemap_index_html.9p",
        "sitemap_index_html.npfs",
        "sitemap_index_html.fh",
        "sitemap_index_html.ofs",
        "sitemap_index_html.hpfs",
        "sitemap_index_html.befs",
        "sitemap_index_html.gpfs",
        "sitemap_index_html.wufs",
        "sitemap_index_html.cramfs",
        "sitemap_index_html.efs",
        "sitemap_index_html.ntfs3g",
        "sitemap_index_html.ufs",
        "sitemap_index_html.romfs",
        "sitemap_index_html.squashfs",
        "sitemap_index_html.ubifs",
        "sitemap_index_html.yaffs",
        "admin/user",
        "admin/pictures",
        "admin/files",
        "admin/docs",
        "admin/logs",
        "user/admin",
        "user/pictures",
        "user/files",
        "user/docs",
        "user/logs",
        "pictures/admin",
        "pictures/user",
        "pictures/files",
        "pictures/docs",
        "pictures/logs",
        "files/admin",
        "files/user",
        "files/pictures",
        "files/docs",
        "files/logs",
        "docs/admin",
        "docs/user",
        "docs/pictures",
        "docs/files",
        "docs/logs",
        "logs/admin",
        "logs/user",
        "logs/pictures",
        "logs/files",
        "logs/docs",
        "admin/user/pictures",
        "admin/user/files",
        "admin/user/docs",
        "admin/user/logs",
        "admin/pictures/files",
        "admin/pictures/docs",
        "admin/pictures/logs",
        "admin/files/docs",
        "admin/files/logs",
        "admin/docs/logs",
        "user/admin/pictures",
        "user/admin/files",
        "user/admin/docs",
        "user/admin/logs",
        "user/pictures/files",
        "user/pictures/docs",
        "user/pictures/logs",
        "user/files/docs",
        "user/files/logs",
        "user/docs/logs",
        "pictures/admin/user",
        "pictures/admin/files",
        "pictures/admin/docs",
        "pictures/admin/logs",
        "pictures/user/files",
        "pictures/user/docs",
        "pictures/user/logs",
        "pictures/files/docs",
        "pictures/files/logs",
        "pictures/docs/logs",
        "admin/user/pictures/files",
        "admin/user/pictures/docs",
        "admin/user/pictures/logs",
        "admin/user/files/docs",
        "admin/user/files/logs",
        "admin/user/docs/logs",
        "admin/pictures/files/docs",
        "admin/pictures/files/logs",
        "admin/pictures/docs/logs",
        "user/pictures/files/docs",
        "user/pictures/files/logs",
        "user/pictures/docs/logs",
        "admin/user/pictures/files/docs",
        "admin/user/pictures/files/logs",
        "admin/user/pictures/docs/logs",
        "admin/pictures/files/docs/logs",
        "user/pictures/files/docs/logs",
        "admin/user/pictures/files/docs/logs",
        "/user/pictures/files/",
        "/user/pictures/",
        "admin/docs",
        "user/docs",
        "pictures/docs",
        "files/docs",
        "logs/docs",
        "admin/logs",
        "user/logs",
        "pictures/logs",
        "files/logs",
        "admin/user/pictures",
        "admin/user/files",
        "admin/user/docs",
        "admin/user/logs",
        "admin/pictures/files",
        "admin/pictures/docs",
        "admin/pictures/logs",
        "admin/files/docs",
        "admin/files/logs",
        "admin/docs/logs",
        "user/pictures/files",
        "user/pictures/docs",
        "user/pictures/logs",
        "user/files/docs",
        "user/files/logs",
        "user/docs/logs",
        "pictures/files/docs",
        "pictures/files/logs",
        "pictures/docs/logs",
        "/user/pictures/files",
        "/user/pictures/docs",
        "/user/pictures/logs",
        "/user/files/docs",
        "/user/files/logs",
        "/img/members/",
        "img",
        ]

    with open(filename, "w") as wordlist_file:
        for word in wordlist:
            wordlist_file.write(word + "\n")
